"""Add resource name

Revision ID: 04d870437e14
Revises: f8927e919732
Create Date: 2017-04-27 12:31:55.646804

"""

# revision identifiers, used by Alembic.
revision = '04d870437e14'
down_revision = 'f8927e919732'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('resource', sa.Column('name', sa.Text(), nullable=False))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('resource', 'name')
    # ### end Alembic commands ###
